@@ -29,17 +29,20 @@ This controller handles node attachments
 auth controll for mojomojo
 
 =cut
+
 sub auth : Private {
     my ( $self, $c ) = @_;
     return $c->forward('/user/login') unless $c->stash->{user};
 
-    my $perms = $c->check_permissions($c->stash->{'path'}, ($c->user_exists ? $c->user->obj : undef));
-    if ($perms->{'attachment'}) {
+    my $perms =
+        $c->check_permissions( $c->stash->{'path'},
+        ( $c->user_exists ? $c->user->obj : undef ) );
+    if ( $perms->{'attachment'} ) {
         return 1;
     }
 
-    $c->stash->{template}='message.tt';
-    $c->stash->{message}='sorry bubba, you aint got no rights';
+    $c->stash->{template} = 'message.tt';
+    $c->stash->{message}  = 'sorry bubba, you aint got no rights';
     return 0;
 }
 
@@ -55,17 +58,18 @@ sub attachments : Global {
     $c->stash->{template} = 'page/attachments.tt';
     $page = $c->stash->{page};
     if ( my $file = $c->req->params->{file} ) {
-        my $upload=$c->request->upload('file');
-        my (@att) =$c->model("DBIC::Attachment")
-            ->create_from_file ( $page, $file, $upload->tempname,$c->path_to('/') );
-        if (! @att ) {
-            $c->stash->{template}='message.tt';
-            $c->stash->{message}= "Could not create attachment from $file.";
+        my $upload = $c->request->upload('file');
+        my (@att) =
+            $c->model("DBIC::Attachment")
+            ->create_from_file( $page, $file, $upload->tempname, $c->path_to('/') );
+        if ( !@att ) {
+            $c->stash->{template} = 'message.tt';
+            $c->stash->{message}  = "Could not create attachment from $file.";
         }
         $c->res->redirect( $c->req->base . $c->stash->{path} . '.attachments' )
-	        unless $c->stash->{template} eq 'message.tt';
-	}
-    
+            unless $c->stash->{template} eq 'message.tt';
+    }
+
 }
 
 =head2 default
@@ -78,11 +82,10 @@ an attachment id.
 
 sub attachment : Chained CaptureArgs(1) {
     my ( $self, $c, $att ) = @_;
-    $c->stash->{att}=$c->model("DBIC::Attachment")->find($att);
-    $c->detach('default') unless ($c->stash->{att});
+    $c->stash->{att} = $c->model("DBIC::Attachment")->find($att);
+    $c->detach('default') unless ( $c->stash->{att} );
 }
 
-
 sub defaultaction : PathPart('') Chained('attachment') Args('') {
     my ( $self, $c ) = @_;
     $c->forward('view');
@@ -90,17 +93,17 @@ sub defaultaction : PathPart('') Chained('attachment') Args('') {
 
 sub default : Private {
     my ( $self, $c ) = @_;
-    $c->stash->{template}='message.tt';
-    $c->stash->{message}= "Attachment not found.";
+    $c->stash->{template} = 'message.tt';
+    $c->stash->{message}  = "Attachment not found.";
     return ( $c->res->status(404) );
 }
 
 sub view : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
-    $c->res->output( IO::File->new($c->stash->{att}->filename) ); 
+    $c->res->output( IO::File->new( $c->stash->{att}->filename ) );
     $c->res->headers->header( 'content-type', $c->stash->{att}->contenttype );
-    $c->res->headers->header("Content-Disposition" => "inline; filename=".
-		$c->stash->{att}->name);
+    $c->res->headers->header(
+        "Content-Disposition" => "inline; filename=" . $c->stash->{att}->name );
 }
 
 =head2 download
@@ -112,12 +115,10 @@ content-disposition.
 
 sub download : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
-	my $att=$c->stash->{att};
-	$c->forward('view');
+    my $att = $c->stash->{att};
+    $c->forward('view');
     $c->res->headers->header( 'content-type', $att->contenttype );
-    $c->res->headers->header(
-        "Content-Disposition" => "attachment; filename=" . $att->name 
-    );
+    $c->res->headers->header( "Content-Disposition" => "attachment; filename=" . $att->name );
 }
 
 =head2 thumb
@@ -127,17 +128,16 @@ thumb action for attachments. makes 100x100px thumbs
 =cut
 
 sub thumb : Chained('attachment') Args(0) {
-    my ( $self, $c) = @_;
-	my $att=$c->stash->{att};
+    my ( $self, $c ) = @_;
+    my $att = $c->stash->{att};
     my $photo;
-	unless ($photo=$att->photo) {
-	    return $c->res->body('Can only make thumbnails of photos');
-	}
+    unless ( $photo = $att->photo ) {
+        return $c->res->body('Can only make thumbnails of photos');
+    }
     $photo->make_thumb() unless -f $att->thumb_filename;
-    $c->res->output( IO::File->new($att->thumb_filename) );
+    $c->res->output( IO::File->new( $att->thumb_filename ) );
     $c->res->headers->header( 'content-type', $att->contenttype );
-    $c->res->headers->header(
-        "Content-Disposition" => "inline; filename=" . $att->name );
+    $c->res->headers->header( "Content-Disposition" => "inline; filename=" . $att->name );
 }
 
 =head2  inline (private);
@@ -148,21 +148,19 @@ show inline attachment
 
 sub inline : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
-    my $att=$c->stash->{att};
+    my $att = $c->stash->{att};
     my $photo;
-	unless ($photo=$att->photo) {
-	    return $c->res->body('Can only make inline version of photos');
-	}
+    unless ( $photo = $att->photo ) {
+        return $c->res->body('Can only make inline version of photos');
+    }
     $photo->make_inline unless -f $att->inline_filename;
-    $c->res->output( IO::File->new($att->inline_filename) );
+    $c->res->output( IO::File->new( $att->inline_filename ) );
     $c->detach('default') if $@ =~ m/^Could not open/;
-    $c->res->headers->header( 'content-type',
-        $c->stash->{att}->contenttype );
+    $c->res->headers->header( 'content-type', $c->stash->{att}->contenttype );
     $c->res->headers->header(
-        "Content-Disposition" => "inline; filename=". $c->stash->{att}->name );
+        "Content-Disposition" => "inline; filename=" . $c->stash->{att}->name );
 }
 
-
 =head2 delete
 
 delete the attachment from this node. Will leave the file on the 
@@ -170,7 +168,7 @@ file system.
 
 =cut
 
-sub delete: Chained('attachment') Args(0) {
+sub delete : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
     return unless $c->forward('auth');
     $c->stash->{att}->delete();
@@ -188,11 +186,11 @@ TODO: Write templates for more mime types.
 sub insert : Chained('attachment') Args(0) {
     my ( $self, $c ) = @_;
     return unless $c->forward('auth');
-    my $att=$c->stash->{att};
-    my ($family) = $att->contenttype =~ m|^([^/]+)|; 
+    my $att = $c->stash->{att};
+    my ($family) = $att->contenttype =~ m|^([^/]+)|;
     $c->stash->{family} = 'mimetypes/' . $family . '.tt';
-    $c->stash->{type} = 'mimetypes/'. $att->contenttype . '.tt'; 
-    $c->stash->{append}=$c->view('TT')->render($c,'page/insert.tt');
+    $c->stash->{type}   = 'mimetypes/' . $att->contenttype . '.tt';
+    $c->stash->{append} = $c->view('TT')->render( $c, 'page/insert.tt' );
     $c->forward('/pageadmin/edit');
 }
 
