@@ -9,7 +9,6 @@ use HTML::Strip;
 use Data::Page;
 use Data::Dumper;
 
-
 =head1 NAME
 
 MojoMojo::Controller::Page - Page controller
@@ -47,41 +46,42 @@ sub view : Global {
 
     my ( $path_pages, $proto_pages, $id ) = @$stash{qw/ path_pages proto_pages id /};
 
-# we should always have at least "/" in path pages. if we don't,
-# we must not have had these structures in the stash
+    # we should always have at least "/" in path pages. if we don't,
+    # we must not have had these structures in the stash
 
     return $c->forward('suggest')
-	if $proto_pages && @$proto_pages;
+        if $proto_pages && @$proto_pages;
 
     my $page = $stash->{'page'};
 
     my $user;
 
-    if ($c->config->{'permissions'}{'check_permission_on_view'}) {
-        if ($c->user_exists()) { $user = $c->user->obj; }
+    if ( $c->config->{'permissions'}{'check_permission_on_view'} ) {
+        if ( $c->user_exists() ) { $user = $c->user->obj; }
 
-        my $perms = $c->check_permissions($stash->{'path'}, $user);
-        if (!$perms->{'view'}) {
-            $stash->{'message'} = 'Permission Denied to view '. $page->name;
+        my $perms = $c->check_permissions( $stash->{'path'}, $user );
+        if ( !$perms->{'view'} ) {
+            $stash->{'message'}  = 'Permission Denied to view ' . $page->name;
             $stash->{'template'} = 'message.tt';
             return;
         }
     }
-    
 
     my $content;
 
     my $rev = $c->req->params->{rev};
     if ( $rev && defined $page->content_version ) {
-	    $content = $c->model("DBIC::Content")->find({
-		    page    => $page->id,
-		    version => $rev
-		});
-	    $stash->{rev} = ( defined $content ? $content->version : undef );
-	    unless( $stash->{rev} ) {
-	        $stash->{message} = 'No such revision for '.$page->name;
-	        $stash->{template} = 'message.tt';
-	    }
+        $content = $c->model("DBIC::Content")->find(
+            {
+                page    => $page->id,
+                version => $rev
+            }
+        );
+        $stash->{rev} = ( defined $content ? $content->version : undef );
+        unless ( $stash->{rev} ) {
+            $stash->{message}  = 'No such revision for ' . $page->name;
+            $stash->{template} = 'message.tt';
+        }
     }
     else {
         $content = $page->content;
@@ -89,7 +89,7 @@ sub view : Global {
             $c->detach('/pageadmin/edit');
 
         }
-        $stash->{rev} =  $content->version ;
+        $stash->{rev} = $content->version;
     }
     $stash->{content} = $content;
 
@@ -106,78 +106,81 @@ the entire site or a subtree starting from the current page.
 sub search : Global {
     my ( $self, $c ) = @_;
 
-    my $stash=$c->stash;
+    my $stash = $c->stash;
 
-# number of search results to show per page
+    # number of search results to show per page
     my $results_per_page = 10;
 
     my $page = $c->stash->{page};
     $stash->{template} = 'page/search.tt';
 
-    my $q = $c->req->params->{q} || $c->stash->{query};
+    my $q           = $c->req->params->{q}           || $c->stash->{query};
     my $search_type = $c->req->params->{search_type} || "subtree";
-    $stash->{query} = $q;
+    $stash->{query}       = $q;
     $stash->{search_type} = $search_type;
 
     my $strip = HTML::Strip->new;
 
     my $results = [];
 
-# for subtree searches, add the path info to the query, replacing slashes with X
+    # for subtree searches, add the path info to the query, replacing slashes with X
     my $real_query = $q;    # this is for context matching later
-	if ( $search_type eq "subtree" ) {
-	    my $fixed_path = $page->path;
-	    $fixed_path =~ s/\//X/g;
-	    $q = "_path:$fixed_path* AND " . $q;
-	}
-
-    foreach my $key ( $c->model('Search::Plucene')->query( $q ) ) {
-
-	my ($path_pages) = $c->model('DBIC::Page')->path_pages( $key ) ;
-    my $page=$path_pages->[ @$path_pages - 1 ];
-
-# skip search result depending on permissions
-    my $user;
-    if ($c->config->{'permissions'}{'check_permission_on_view'}) {
-        if ($c->user_exists()) { $user = $c->user->obj; }
-        my $perms = $c->check_permissions($page->path, $user);
-        next unless $perms->{'view'};
+    if ( $search_type eq "subtree" ) {
+        my $fixed_path = $page->path;
+        $fixed_path =~ s/\//X/g;
+        $q = "path:$fixed_path* AND " . $q;
     }
+        
+    my $hits=$c->model('Search')->search($q);
+    while (my $hit = $hits->fetch_hit_hashref ) {
+        $hit->{path} =~ s/X/\//;
+        my ($path_pages) = $c->model('DBIC::Page')->path_pages($hit->{path});
+        my $page = $path_pages->[ @$path_pages - 1 ];
 
-# add a snippet of text containing the search query
-	my $content = $strip->parse( $page->content->formatted($c) );
-	$strip->eof;
+        # skip search result depending on permissions
+        my $user;
+        if ( $c->config->{'permissions'}{'check_permission_on_view'} ) {
+            if ( $c->user_exists() ) { $user = $c->user->obj; }
+            my $perms = $c->check_permissions( $page->path, $user );
+            next unless $perms->{'view'};
+        }
 
-# FIXME: Bug? Some snippet text doesn't get displayed properly by Text::Context
-	my $snippet = Text::Context->new( $content, split(/ /, $real_query) );
+        # add a snippet of text containing the search query
+        my $content = $strip->parse( $page->content->formatted($c) );
+        $strip->eof;
 
-	my $result = {
-	    snippet => $snippet->as_html,
-	    page => $page,
-	};
-	push @$results, $result;
+        # FIXME: Bug? Some snippet text doesn't get displayed properly by Text::Context
+        my $snippet = Text::Context->new( $content, split( / /, $real_query ) );
+
+        my $result = {
+            snippet => $snippet->as_html,
+            page    => $page,
+        };
+        push @$results, $result;
     }
 
     my $result_count = scalar @$results;
-    if ( $result_count ) {
-# Paginate the results
-# This is done even with even 1 page of results so the template doesn't need to do
-# two separate things
-	my $pager = Data::Page->new;
-	$pager->total_entries( $result_count );
-	$pager->entries_per_page( $results_per_page );
-	$pager->current_page( $c->req->params->{p} || 1 );
+    if ($result_count) {
 
-	if ( $result_count > $results_per_page ) {
-# trim down the results to just this page
-	    @$results = $pager->splice( $results );
-	}
+        # Paginate the results
+        # This is done even with even 1 page of results so the template doesn't need to do
+        # two separate things
+        my $pager = Data::Page->new;
+        $pager->total_entries($result_count);
+        $pager->entries_per_page($results_per_page);
+        $pager->current_page( $c->req->params->{p} || 1 );
 
-	$c->stash->{pager} = $pager;
-	my $last_page = ( $pager->last_page > 10 ) ? 10 : $pager->last_page;
-	$c->stash->{pages_to_link} = [ 1 .. $last_page ];
-	$c->stash->{results} = $results;
-	$c->stash->{result_count} = $result_count;
+        if ( $result_count > $results_per_page ) {
+
+            # trim down the results to just this page
+            @$results = $pager->splice($results);
+        }
+
+        $c->stash->{pager} = $pager;
+        my $last_page = ( $pager->last_page > 10 ) ? 10 : $pager->last_page;
+        $c->stash->{pages_to_link} = [ 1 .. $last_page ];
+        $c->stash->{results}       = $results;
+        $c->stash->{result_count}  = $result_count;
     }
 }
 
@@ -204,14 +207,15 @@ sub inline_tags : Global {
     $c->stash->{template}  = 'page/tags.tt';
     $c->stash->{highlight} = $highlight;
     my $page = $c->stash->{page};
-    if ($c->user_exists) {
+    if ( $c->user_exists ) {
         my @tags = $page->others_tags( $c->user->obj->id );
         $c->stash->{others_tags} = [@tags];
         @tags                    = $page->user_tags( $c->user->obj->id );
         $c->stash->{taglist}     = ' ' . join( ' ', map { $_->tag } @tags ) . ' ';
         $c->stash->{tags}        = [@tags];
-    } else {
-        $c->stash->{others_tags}      = [ $page->tags_with_counts ];
+    }
+    else {
+        $c->stash->{others_tags} = [ $page->tags_with_counts ];
     }
 }
 
@@ -223,16 +227,16 @@ all nodes in this namespace
 
 sub list : Global {
     my ( $self, $c, $tag ) = @_;
-    my $page=$c->stash->{page};
-    $c->stash->{tags}      = $c->model("DBIC::Tag")->most_used();
+    my $page = $c->stash->{page};
+    $c->stash->{tags} = $c->model("DBIC::Tag")->most_used();
     $c->detach('/tag/list') if $tag;
     $c->stash->{template} = 'page/list.tt';
-    $c->stash->{pages}    =  [$page->descendants];
+    $c->stash->{pages}    = [ $page->descendants ];
 
     # FIXME - real data here please
     $c->stash->{orphans}   = [];
     $c->stash->{backlinks} = [ $c->model("DBIC::Link")->search( to_page => $page->id ) ];
-    $c->stash->{wanted}    = [ $c->model("DBIC::WantedPage")->search()];
+    $c->stash->{wanted}    = [ $c->model("DBIC::WantedPage")->search() ];
 }
 
 =head2 recent (.recent)
@@ -243,9 +247,9 @@ recently changed nodes in this namespace.
 
 sub recent : Global {
     my ( $self, $c, $tag ) = @_;
-    $c->detach('/tag/recent',[$tag]) if $tag;
-    $c->stash->{tags}     = $c->model("DBIC::Tag")->most_used;
-    my $page=$c->stash->{page};
+    $c->detach( '/tag/recent', [$tag] ) if $tag;
+    $c->stash->{tags} = $c->model("DBIC::Tag")->most_used;
+    my $page = $c->stash->{page};
     $c->stash->{template} = 'page/recent.tt';
     $c->stash->{pages}    = [ $page->descendants_by_date ];
 
@@ -258,7 +262,7 @@ overview of available feeds for this node.
 
 =cut
 
-sub feeds  : Global {
+sub feeds : Global {
     my ( $self, $c ) = @_;
     $c->stash->{template} = 'feeds.tt';
 }
@@ -311,7 +315,7 @@ Highlight changes for save.
 
 sub highlight : Global {
     my ( $self, $c ) = @_;
-    $c->stash->{render} =  'highlight';
+    $c->stash->{render} = 'highlight';
     $c->forward('view');
 }
 
